
;'EOLO' modchip by USB 28-10-2001 for USA and EUROPE PS2 (www.elotrolado.net)



;--------------------------------------------------------------------------
;               
;                 ESQUEMA DE CONEXIONES PIC12c508A
;                
;   
;                        __________________
;                        |      \__/      |
;            [1] +5VCC  O|-1--||--------8-|O MASA         [8]
;                        |  100nf opcional|
;            [2] DVDOUT O| 2            7 |O SHORT BRAKE  [9] (PIN 18 BA6664) 
;                        |    12c508a     |                 + -      R *
;            [3] DVDIN  O| 3            6 |O TX_SCEE [6]----||----\/\/\---->[6] 12          
;                        |                |              1uF/63v    
;       |----- PULSADOR O| 4            5 |O MOTOR PULSE  [5]       
;     | o                |                |                      
;   --|       		 ------------------
;     | o               
;       |               
;      --- MASA 

;--------------------------------------------------------------------------
;               
;                 ESQUEMA DE CONEXIONES PIC16F84A
;                
;   
;                        __________________
;                        |      \__/      |
;                       O| 1           18 |O             
;                        |                |
;                       O| 2    PIC    17 |O                                  
;                        |    16F84A      |      
;                       O| 3           16 |O---|  
;                        |                |   [|] 4 Mhz/8Mhz/12Mhz
;             [1] +5VCC O| 4______     15 |O---|
;                        |        \       |       27pf
;             [8] MASA  O|-5-||----\___14 |O +5VCC [1]
;                        |   100nF        |
;            [2] DVDOUT O| 6  opcional 13 |O                                            
;                        |                |                 + -      R *
;             [3] DVDIN O| 7           12 |O TX_SCEE [6]----||----\/\/\---->[6] 12          
;                        |                |              1uF/63v    
;       |----- PULSADOR O| 8           11 |O MOTOR PULSE [5]       
;     | o                |                |
;   --|       		O| 9           10 |O SHORT BRAKE  [9] (PIN 18 BA6664)       
;     | o                |                |
;       |                ------------------
;      --- MASA

;  * RESISTENCIA: Esto es opcional, se puede poner como precaucion o en caso de tener problemas
; lo logico seria poner una resistencia variable de 1k y poner el valor mas alto que funcione.
; para las V3, el valor puede esta entre los 180 ohmios 220 ohmios (un poco menos de1/4 de cursor)
; para las V4, hay quien dice que casi medio cursor para que el chip funcione

;NOTA: CONEXIONES PARA EL CHIP 'EOLO' (los puntos entre '[]' SON LOS DE LA PLACA)

;TODOS LOS PUNTOS IGUAL QUE EL MONTAJE DEL 8MOD, EXCEPTO [7] [9] Y [10]
;[1] +5VCC - SIN COMENTARIOS 
;[2] DVD_OUT - ES IGUAL A 1 CUANDO LA BANDEJA DEL DVD ESTA SALIENDO 
;[3] DVD_IN - ES IGUAL A 1 CUANDO LA BANDEJA DEL DVD ESTA ENTRANDO 

;[5] MOTOR_PULSE - ENVIO DE PULSOS AL MOTOR DE LA BANDEJA DEL DVD 
;[6] TX_SCEE - ES POR DONDE TRANSMITE VIA SERIE "SCEE" 

;[8] MASA - SIN COMENTARIOS 
;[9] SHORT BRAKE- SEAL QUE AL PONERSE A 1 FRENA EL MOTOR DEL CD (NECESARIO EN V4)


;///////////////////////////////////
;/ FUNCIONAMIENTO
;///////////////////////////////////

;NOTA: Hay que tener en cuenta, que como este chip no coge la seal de RESET, no puede cambiar de 
;modo automaticamente. Es decir, si estamos en modo especial para copias o en el normal y se
;ha dejado de enviar 'SCEE' por que ha caducado el tiempo y hacemos RESET, las copias fallaran
; para solucionarlo, simplemente apagar la consola o expulsar la bandeja y entrara de nuevo
; el modo SCEE

; 1) DESCONEXION DE CHIP: Pulsar el pulsador EA y encender la consola desde el RESET y soltar
; al cabo de un segundo el EA. Permanece en este modo hasta que la consola se apague
; 2) METODO PARA COPIAS PSX Y PS2 'NORMALES'. Este es el metodo por defecto (tambien admite originales, con
; la nueva temporizacion). Tiene una desconexion automatica al cabo de 5 min y se activa siempre
; que abramos la bandeja desde el boton de la PS2
; 3) METODO EA MANUAL: Simplemente pulsar el pulsador EA (como un segundo) y al cabo de 4 segundos,
; saldra la bandeja. Para introducirla de nuevo, hay que volver a pulsar el EA

; 4) METODO ESPECIAL PS2 NORMALES:  Este metodo esta pensado para cuidar aun mas la lente de la PS2.
; Para la copias de PS2, solo es necesario enviar durante unos instantes el codigo SCEE (no dos veces
; como en los juegos de PSX) asi que podemos estar seguros que al cerrar la bandeja, si enviamos unos
; pocos  SCEE, el juego entrara. Para activarlo, primero pulsamos el metodo EA para sacar la bandeja
; y cuando cambiemos el disco, para cerrar PULSAMOS EL BOTON DE LA PS2 que controla la bandeja. Asi
; de facil. Envia el SCEE durante 12 segundos y despues se queda en estado 'latente'. Tambien vale
; ahora, expulsar la bandeja normalmente y luego cerrar con el boton EA

; NOTAS SOBRE XTREME/AR2: CUANDO SE CAMBIE EL DISCO EN EL MODO PARA COPIAS/ORIGINALES, ESPERAR UNOS SEGUNDOS A QUE LA PS2
;   RECONOZCA EL CD ANTES DE PULSAR X (ES MEJOR ASI)


;--------------------------------------------------------------------------

;*****************************************************************************************************************************
;ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION ATENCION
;*****************************************************************************************************************************

; PROCESADOR A EMPLEAR PIC16F84A 0 12C508A CRISTAL 4,8,12 MHZ, EUROPA/USA

;16f84a       PICPROC F12MHZ FHIGH ZONA
;4Mhz  EUR       1      0      0     0
;8Mhz  EUR       1      1      0     0
;12Mhz EUR       1      1      1     0
;4Mhz  USA       1      0      0     1
;8Mhz  USA       1      1      0     1
;12Mhz USA       1      1      1     0

;12C508       PICPROC=1;

PICPROC EQU 1          ;0=PIC12c508a 1=PIC16F84A TIPO

;seleccion de frequencia (no afecta en 12c508a)
F12MHZ EQU 1        ;0=4MHZ 1=12MHZ         FRECUENCIA DEL CRISTAL
FHIGH  EQU 1        ; SI F12MHZ ENTONCES SI 0- 8MHZ  1-12MHZ (JEJE UN POCO REBUSCADO NO?)  

ZONA EQU 0          ;0-EUROPA 1-AMERICA


 IF        PICPROC
 list      p=16F84A
 include   "p16F84A.inc"

;-----------------------------------------------------------------------
; SIN POWER ON RESET, SIN PROTEJER, SIN WASDOG Y CON OSCILADOR EXTERNO 
;-----------------------------------------------------------------------
 __FUSES _PWRTE_OFF & _CP_OFF & _WDT_ON & _XT_OSC

 ELSE
 list      p=12C508A
 include   "p12C508A.inc"

   

;-----------------------------------------------------------------------
; FUSIBLES, WASDOG, OSCILADOR ETC.. 
;-----------------------------------------------------------------------
 __FUSES _MCLRE_OFF & _CP_OFF & _WDT_ON & _IntRC_OSC

 ENDIF





;ͻ
; NOTACION DECIMAL 
;ͼ
 radix   dec
;--------------------------------------------------------------------------

;ͻ
; VARIABLES DE RAM INTERNA 
;ͼ
 cblock 0x0c
        RAM_0C  ;Contador pausa
        RAM_0D  ;Contador
        RAM_0E  ;Contador
        RAM_0F  ;Cantidad de bytes a enviar de la tabla
        RAM_10  ;Cantidad de bits a enviar del byte
        RAM_11  ;Contador W en pausa Wx199
        RAM_12  ;Contador 199 en pausa Wx199
        RAM_13  ;Byte leido de la tabla
        RAM_14  ;Puntero del byte de la tabla
        RAM_15  ;Mascara del estado de los bits del puerto A
        RAM_16  ;Mascara del estado de los bits del puerto B

        endc

;-----------------------
; macros
;-----------------------
INIT_PORTS macro
 IF PICPROC	
	movlw   b'11111111'     ;INICIALIZA TODOS LOS
	movwf   RAM_16 
        tris    PORTB            ;PUERTOS EN ALTO Y
	movwf   RAM_16 
	tris    PORTA 
 ELSE
	movlw   b'11111111'     ;INICIALIZA TODOS LOS
	movwf   RAM_16 
	tris    GPIO            ;PUERTOS EN ALTO Y
 ENDIF
 endm



;ͻ
; DEFINICION DE LOS PINES DEL PIC 
;ͼ
       
 IF PICPROC
     	#define  TX_SCEE   PORTB,6
	#define  DVD_IN    PORTB,1    
	#define  DVD_OUT    PORTB,0    
 ELSE
     	#define  TX_SCEE   GPIO,1
	#define  DVD_IN    GPIO,4  
	#define  DVD_OUT    GPIO,5  
 ENDIF
;--------------------------------------------------------------------------

 IF PICPROC
;---------------------------
; VECTOR DE RESET EN 16F84A
;---------------------------
	org	0x0
        goto    COMIENZO        ;SALTA AL COMIENZO DEL PROGRAMA

;----------------------------------
; VECTOR DE INTERRUPCION EN 16F84A
;----------------------------------
 
        org     0x4
        retfie
 ELSE
;-----------------------------
; VECTOR DE RESET EN 12C508A
;-----------------------------
	org	0x0
        movwf   OSCCAL          ;CALIBRA EL OSCILADOR INTERNO
        goto    COMIENZO        ;SALTA LA COMIENZO DEL PROGRAMA
 ENDIF

TABLA   
	addwf   PCL,F           ;TABLA PARA LA PS2 EUROPEA
 IF ZONA
	retlw   'S'
        retlw   'C'
        retlw   'E'
        retlw   'A'
 ELSE
        retlw   'S'
        retlw   'C'
        retlw   'E'
        retlw   'E'
 ENDIF
 IF 0
        
        retlw   'S'
        retlw   'C'
        retlw   'E'
        retlw   'I'
 ENDIF

;--------------------------------------------------------------------------
	retlw   ' '
        retlw   'E'
        retlw   'O'
        retlw   'L'
        retlw   'O'
        retlw   ' '
	retlw   'V'
	retlw   '3'
       

        
        retlw   ' '
        retlw   'B'
        retlw   'Y'
        retlw   ' '
        retlw   'U'
        retlw   'S'
        retlw   'B'
        retlw   ' '
        retlw   'V'
        retlw   'K'
        retlw   ' '
	retlw   'F'
	retlw   'O'
	retlw   'R'
	retlw   ' '
	
 IF PICPROC
	retlw   '1'
	retlw   '6'
	retlw   'F'
	retlw   '8'
	retlw   '4'
	retlw   'A'
	retlw   ' '
 IF F12MHZ
 IF FHIGH
	retlw   '1'
	retlw   '2'
	retlw   'M'
	retlw   'h'
	retlw   'z'
	retlw   ' '
	
 ELSE
	retlw   '8'
	retlw   'M'
	retlw   'h'
	retlw   'z'
	retlw   ' '
	
 ENDIF
 ELSE
	retlw   '4'
	retlw   'M'
	retlw   'h'
	retlw   'z'
	retlw   ' '
 ENDIF
 ELSE
	retlw   '1'
	retlw   '2'
	retlw   'C'
	retlw   '5'
	retlw   '0'
	retlw	'8'
	retlw   'A'
	retlw   ' '
	retlw   '4'
	retlw   'M'
	retlw   'h'
	retlw   'z'
	retlw   ' '
 ENDIF	
 
;--------------------------------------------------------------------------

;--------------------------------------------------------------------------
BOTON
	goto BOTON2
ENVIASCEE
	goto ENVIASCEE2

;ͻ
; COMIENZO DEL PROGRAMA 
;ͼ
COMIENZO
 IF PICPROC
        movlw   b'11001111'     ;CONFIGURA WDT PRESCALER = 1:128
        option          
	
        movlw   b'11111111'     ;INICIALIZA TODOS LOS PUERTOS
        movwf   RAM_15          ;EN ALTO Y SUS MASCARAS RAM_15 Y RAM_16
        movwf   RAM_16          ;
        tris    PORTA           ;
        tris    PORTB           ;
 ELSE
	movlw   b'11001111'     ;CONFIGURA WDT PRESCALER = 1:128
        option                  ;OSCILADOR = 4MHZ        
        movlw   255             ;INICIALIZA TODOS LOS PUERTOS
        movwf   RAM_16          ;EN ALTO Y RAM_16
	tris	GPIO		;
 ENDIF
	
; PAUSA DE ARRANQUE (SE MANTIENE POR 'TRADICION', PERO PODRIA SER MAYOR)
        movlw   2               ;100 MILISEGUNDOS 
        movwf   RAM_0D          ;
ETI_107 call    PAUSA50MSG      ;       +
        decfsz  RAM_0D,F        ;
        goto    ETI_107         ;
        movlw   6               ;300 MILISEGUNDOS
        movwf   RAM_0D          ;
ETI_10C call    PAUSA50MSG      ;       +
        decfsz  RAM_0D,F        ;
        goto    ETI_10C         ;
        movlw   14              ;14 MILISEGUNDOS
        call    PAUSAWX1MSG     ;
;--------------------------------------------------------------------------


	movlw 30 	; fija tiempo en 3 minutos para SCEE (30 * 6 seg)
        movwf   RAM_0E   

; bucle que evalua si se DESCONECTA el chip (comprueba durante 1 seg)
        movlw   20             
        movwf   RAM_0D          
ETI_115a 
	
	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION1
        call    PAUSA50MSG      
        decfsz  RAM_0D,F        
        goto    ETI_115a
	goto OPCION2



;ͻ
; OPCION 1 (RESET NO PULSADO) EL MODCHIP SE         
; DESHABILITA Y SOLO PODEMOS USAR JUEGOS ORIGINALES 
;ͼ
OPCION1
       
        INIT_PORTS
OP_1    
	movlw 1
	call PAUSAWX1MSG 

        goto    OP_1         
       
        goto OPCION2



OPCION3
       
           
        INIT_PORTS
	
; retardo de seguridad para DVD (si se ha abierto la bandeja por metodo normal y se pulsa el boton
; EA, este se queda esperando hasta que hayan pasado al menos, 12 segundos


; sistema de apertura
OPEN

 IF PICPROC     
	movlw   b'01111111'     ;   pone el dato para frenar
        movwf   PORTB            ;   
        movlw   b'11101111'     ;    el giro del CD (EN 16F84A)
       	tris 	PORTB
 ELSE	
	movlw   b'11111111'     ;   pone el dato para frenar
        movwf   GPIO            ;   
        movlw   b'11111110'     ;    el giro del CD (EN 12C508A)
       	tris 	GPIO
	
 ENDIF

	movlw   50              ; FRENO (5 segundos) 100%
        movwf   RAM_0D  
ope_1b 
       

        movlw   100             
        call    PAUSAWX1MSG                      
	      
        decfsz  RAM_0D,F        
        goto    ope_1b           
        call Abrir     
	movlw   b'11111111'     ; FIN FRENO
 IF PICPROC
	
       	tris 	PORTB   
 ELSE
        tris GPIO
 ENDIF                  

	movlw 4          ; fija tiempo en 12 segundos para SCEE (metodo copias PS2 ESPECIAL,seria 4*3 seg)
        movwf   RAM_0E  

PAUSAENOPEN
        call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto CIERRA
	movlw 50
	call PAUSAWX1MSG

        btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    PAUSAENOPEN         ;DE LA BANDEJA DEL DVD
	nop
	nop	
	nop
	nop
	btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    PAUSAENOPEN         ;DE LA BANDEJA DEL DVD
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX

 
CIERRA  
       
        call Cerrar;


;/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
;// OPCION QUE HABILITA EL CHIP (MODO PSX) SI ES LO QUE QUEREMOS (NO HACE NADA HASTA QUE PULSAMOS RESET O EXPULSAR BANDEJA) //
;/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ESPERAENEA
        call BOTON
        andlw 0xff
	btfss STATUS,Z
        goto OPCION3

	movlw 30          ; fija tiempo en 3 minutos para SCEE (30 * 6 seg)
        movwf   RAM_0E  
	movlw 5
        movwf   RAM_0C        ; fija el bucle para un retardo de 250ms (5*50)
Ew_1    call PAUSA50MSG
        btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    Ew_2         ;DE LA BANDEJA DEL DVD
	nop
	nop	
	nop
	btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    Ew_2         ;DE LA BANDEJA DEL DVD
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX
Ew_2 
	decfsz RAM_0C,F
	goto Ew_1
	goto ESPERAENEA

ESPERAENOPEN
	movlw   b'11111111' 
	movwf    RAM_16
 IF PICPROC     
	tris    PORTB           
 ELSE
	tris	GPIO
 ENDIF

Esopen
	movlw 50                   ; espera a que se abra del todo la bandeja
	call  PAUSAWX1MSG

	btfsc   DVD_OUT
	goto Esopen
	nop
	nop
	nop
	nop
	nop
	nop
	btfsc   DVD_OUT
	goto Esopen
        call BOTON
        andlw 0xff
	btfsc STATUS,Z
        goto Ow_0
	call Cerrar      ; como estaba abierta el boton EA si se pulsa debe cerrar y poner modo especial
	movlw 4          ; fija tiempo en 12 segundos para SCEE (metodo copias PS2 ESPECIAL,seria 4*3 seg)
        movwf   RAM_0E  
	goto OPCION2

Ow_0
	movlw 30          ; fija tiempo en 3 minutos para SCEE (30 * 6 seg)
        movwf   RAM_0E  
	movlw 5 
        movwf   RAM_0C   ; bucle de retardo 250ms (5 X 50)
Ow_1    call PAUSA50MSG
        btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    Ow_2         ;DE LA BANDEJA DEL DVD
	nop
	nop	
	nop
	btfss   DVD_IN          ;ESPERA A QUE PULSEMOS LA APERTURA
        goto    Ow_2         ;DE LA BANDEJA DEL DVD
        goto    OPCION2         ;PARA PASAR A MODO CHIP PSX
Ow_2 
	decfsz RAM_0C,F
	goto Ow_1
	goto Esopen ; bucle infinito
;--------------------------------------------------------------------------

Abrir  				; EL MODCHIP FUERZA A LA CONSOLA
	movlw   100
        movwf   RAM_0D          ;PARA QUE EXPULSE LA BANDEJA DEL DVD
ETI_132 
	
 IF PICPROC
	movlw   b'10111001'    
        movwf   PORTB          
        movlw   b'11001110'    
        tris    PORTB          
 ELSE
	movlw   b'00100101'   
        movwf   GPIO           
        movlw   b'11011010'  
        tris	GPIO 
 ENDIF
	

        movlw   10            
        call    PAUSAWX1MSG    
 


 IF PICPROC
	movlw   b'10011001'    
        movwf   PORTB          
	movlw   b'11001110'  
        tris    PORTB         
 ELSE
	movlw   b'00100001'    
        movwf   GPIO           
        movlw   b'00011010'     
        tris    GPIO           
 ENDIF
	
	movf   RAM_0D,W 	
	andlw b'11000000'       ; cambio de velocidad en bandeja
	movlw 15
        btfss STATUS,Z     
	movlw 10              
        call    PAUSAWX1MSG    
 
        decfsz  RAM_0D,F        
        goto    ETI_132         

        movlw   b'11111111' 
 IF PICPROC    
        tris    PORTB   
 ELSE
        tris	GPIO
 ENDIF        
        
        retlw 1
Cerrar
	movlw   100              ;EL MODCHIP FUERZA A LA CONSOLA
        movwf   RAM_0D          ;PARA QUE INTRODUZCA LA BANDEJA DEL DVD
ETI_14A 
	    
 IF PICPROC
	movlw   b'10111010'     
        movwf   PORTB          
        movlw   b'11011101'    
        tris    PORTB           
 ELSE
	movlw   b'00010100'     
        movwf   GPIO           
        movlw   b'11101011'    
        tris    GPIO       
 ENDIF
        movlw   10            
        call    PAUSAWX1MSG     
 IF PICPROC             
	movlw   b'10011010'  
        movwf   PORTB           
        movlw   b'11011101'    
        tris    PORTB         
 ELSE
	movlw   b'00010000'     
        movwf   GPIO           
        movlw   b'11101011'     
        tris    GPIO       
 ENDIF
	movf   RAM_0D,W 	
	andlw b'11000000'       ; cambio de velocidad en bandeja
	movlw 10
        btfss STATUS,Z          
	movlw 15             
        call    PAUSAWX1MSG    
        decfsz  RAM_0D,F          
        goto    ETI_14A               


	movlw   b'11111111'    

 IF PICPROC
        tris    PORTB       
 ELSE
	tris    GPIO        
 ENDIF
        retlw 1
;	nop;

	



PAUSA50MSG
        movlw   50              ;
;ͻ
; PAUSA DE (W x 1 MILISEGUNDO) 
;ͼ
PAUSAWX1MSG
        movwf   RAM_11          ;
ETI_042 movlw   199             ;
        movwf   RAM_12          ;
ETI_044 clrwdt                     ;
        nop                    ;

 IF PICPROC
 IF F12MHZ
 IF FHIGH
        nop
        nop
        nop
        nop
        clrwdt
 ENDIF
        nop
        nop
        nop
        nop
        clrwdt
 ENDIF
 ENDIF
        decfsz  RAM_12,F        ;
        goto    ETI_044         ;
        nop
     
 IF PICPROC
 IF F12MHZ
 IF FHIGH
        nop
        nop
        nop
        nop
        clrwdt
 ENDIF
        nop
        nop
        nop
        nop
        clrwdt
 ENDIF	    
 ENDIF                   
        decfsz  RAM_11,F        ;
        goto    ETI_042         ;
        return                  ;
;--------------------------------------------------------------------------
OPCION2
       
       
        ;INICIALIZA PUERTOS   
        INIT_PORTS
                
        
        
BUCLEA2
       
 
; SEMICICLO DE ORIGINALES
        
        movf   RAM_0E,W 	; si el tiempo es menor que 8
	andlw b'11111000'       ; no se hacen pausas para originales
        btfsc STATUS,Z          ; (modo especial para copias PS2)
        goto SEMICOPIAS

 IF PICPROC
	bsf     RAM_16,6   
	movf    RAM_16,W        
	tris    PORTB          
 ELSE
	bsf     RAM_16,1   
	movf    RAM_16,W        
	tris    GPIO     

 ENDIF
	movlw   12             ;12 VECES (3 segundos)
	movwf   RAM_0D         ;REPETIRA LA PAUSA (DEL TAMAO DE UNA TRANSMISION)
ETI_o
	btfss   DVD_OUT
	goto ETI_o1
	nop
        nop
	nop
	nop
	nop
	nop
	btfsc   DVD_OUT
	goto ESPERAENOPEN
ETI_o1 
	movlw   250               
	call    PAUSAWX1MSG  
	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3
      
	decfsz  RAM_0D,F        
	goto    ETI_o
 
; SEMICICLO COPIAS (ENVIA SCEE) 
SEMICOPIAS
	movlw   12             ;12 VECES (3 segundos)
	movwf   RAM_0D          ;REPETIRA LA TRANSMISION
ETI_122
	btfss   DVD_OUT
	goto ETI_o2
	nop
        nop
	nop
	nop
	nop
	nop
	btfsc   DVD_OUT
	goto ESPERAENOPEN
ETI_o2 
   	call BOTON
        andlw 0xff
        btfss STATUS,Z
        goto OPCION3

	clrf    RAM_14          ;INICIALIZA PUNTERO A TABLA Y
	call    ENVIASCEE       ;TRANSMITE VIA SERIE 8 VECES 'SCEE
      

	decfsz  RAM_0D,F    
	goto    ETI_122 
	decfsz  RAM_0E,F        ;
       	goto BUCLEA2
	movlw   b'11111111' 
	movwf    RAM_16
 IF PICPROC     
	tris    PORTB           
 ELSE
	tris	GPIO
 ENDIF
	goto ESPERAENEA     


ENVIASCEE2
        ; 250 milisegundos (lo que nos dice que se cargan 16 sectores a 1x que curioso verdad?)
       
        movlw   74              ;74 MILISEGUNDOS DE ESPACIO ENTRE
        call    PAUSAWX1MSG     ;ENTRE TRANSMISION Y TRANSMISION

        movlw   4               ;ENVIAREMOS 4 BYTES
        movwf   RAM_0F          ;DE LA TABLA
ETI_068
        movf    RAM_14,W        ;LEEMOS 1 BYTE DE
        call    TABLA           ;LA TABLA
        movwf   RAM_13          ;EN RAM_13
        comf    RAM_13,F        ;

        movlw   8               ;ENVIAREMOS 8
        movwf   RAM_10          ;BITS DE CADA BYTE
 IF PICPROC
        bsf     RAM_16,6        ;ENVIA EL BIT DE START VIA SERIE
        movf    RAM_16,W        ; 16F84A
        tris    PORTB           ;
 ELSE
	bsf     RAM_16,1        ;ENVIA EL BIT DE START VIA SERIE
        movf    RAM_16,W        ; 12C508A
        tris    GPIO           ;
 ENDIF

        movlw   4               ;4 MILISEGUNDOS DEL ANCHO DEL BIT DE START
        call    PAUSAWX1MSG     ;

ETI_073
        rrf     RAM_13,F        ;ENVIA 1 BIT DEL BYTE VIA SERIE
 IF PICPROC
        movlw   b'10111111'     ; PIC 16F84A
        movwf   PORTB           ;
        btfsc   STATUS,0        ;
        bsf     RAM_16,6        ;
        btfss   STATUS,0        ;
        bcf     RAM_16,6        ;
        movf    RAM_16,W        ;
        tris    PORTB           ;
 ELSE
	movlw   b'11111101'     ; PIC 12C508A
        movwf   GPIO           ;
        btfsc   STATUS,0        ;
        bsf     RAM_16,1        ;
        btfss   STATUS,0        ;
        bcf     RAM_16,1        ;
        movf    RAM_16,W        ;
        tris    GPIO           ;
 ENDIF

        movlw   4               ;4 MILISEGUNDOS DEL ANCHO DEL BIT
        call    PAUSAWX1MSG     ;

        decfsz  RAM_10,F        ;CONTINUAMOS HASTA
        goto    ETI_073         ;ENVIAR LOS 8 BITS DEL BYTE

 IF PICPROC
        bcf     RAM_16,6        ;ENVIA 2 BITS DE STOP EN 16F84A
        movf    RAM_16,W        ;
        tris    PORTB           ;
 ELSE
	bcf     RAM_16,1        ;ENVIA 2 BIT DE STOP EN 12C508A
        movf    RAM_16,W        ;
        tris    GPIO           ;
 ENDIF

        movlw   8               ;8 MILISEGUNDOS DEL ANCHO DE
        call    PAUSAWX1MSG     ;LOS 2 BITS DE STOP

	

        incf    RAM_14,F        ;INCREMENTA PUNTERO DE LA TABLA

        decfsz  RAM_0F,F        ;CONTINUA HASTA
        goto    ETI_068         ;ENVIAR LOS 4 BYTES DE LA TABLA
       
        return                  ;RETORNA



;// DETECTA SI SE HA PULSADO EL BOTON DE EXPULSION
BOTON2   
        movlw 1
	call PAUSAWX1MSG
 IF PICPROC
	movlw   b'01001111'     ;activa pull-up EN 16F84A
        option    
	nop
	btfsc PORTB,2       ; deteccion pulsador 
	goto BOT_NOOK
	nop
	nop
	nop
	btfsc PORTB,2       ; deteccion pulsador (comprobaacion de seguridad)
	goto BOT_NOOK
 ELSE
	movlw   b'10001111'     ;activa pull-up EN 12C508A
        option    
	nop
	btfsc GPIO,3       ; deteccion pulsador 
	goto BOT_NOOK
	nop
	btfsc GPIO,3       ; deteccion pulsador (comprobacion de seguridad)
	goto BOT_NOOK
 ENDIF
	movlw   b'11001111'     ;desactiva pull-up (de lo contrario el chip no funcionaria bien)
        option    
	retlw 0xff
BOT_NOOK	
	movlw   b'11001111'     ;desactiva pull-up
        option    
	retlw 0x0
      	
	end

